"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireWildcard(require("react"));

var _core = require("@sheets-editor/core");

var _DropdownIcon = require("./DropdownIcon");

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

const languages = [{
  value: 'abap',
  label: 'ABAP'
}, {
  value: 'bash',
  label: 'Bash'
}, {
  value: 'basic',
  label: 'BASIC'
}, {
  value: 'c',
  label: 'C'
}, {
  value: 'clojure',
  label: 'Clojure'
}, {
  value: 'coffeescript',
  label: 'CoffeeScript'
}, {
  value: 'cpp',
  label: 'C++'
}, {
  value: 'csharp',
  label: 'C#'
}, {
  value: 'css',
  label: 'CSS'
}, {
  value: 'dart',
  label: 'Dart'
}, {
  value: 'docker',
  label: 'Docker'
}, {
  value: 'elixir',
  label: 'Elixir'
}, {
  value: 'elm',
  label: 'Elm'
}, {
  value: 'erlang',
  label: 'Erlang'
}, {
  value: 'flow',
  label: 'Flow'
}, {
  value: 'fortran',
  label: 'Fortran'
}, {
  value: 'fsharp',
  label: 'F#'
}, {
  value: 'gherkin',
  label: 'Gherkin'
}, {
  value: 'glsl',
  label: 'GLSL'
}, {
  value: 'go',
  label: 'Go'
}, {
  value: 'graphql',
  label: 'GraphQL'
}, {
  value: 'groovy',
  label: 'Groovy'
}, {
  value: 'html',
  label: 'HTML'
}, {
  value: 'java',
  label: 'Java'
}, {
  value: 'javascript',
  label: 'Javascript'
}, {
  value: 'json',
  label: 'JSON'
}, {
  value: 'kotlin',
  label: 'Kotlin'
}, {
  value: 'latex',
  label: 'LaTeX'
}, {
  value: 'less',
  label: 'Less'
}, {
  value: 'lisp',
  label: 'Lisp'
}, {
  value: 'livescript',
  label: 'Livescript'
}, {
  value: 'makefile',
  label: 'Makefile'
}, {
  value: 'markdown',
  label: 'Markdown'
}, {
  value: 'markup',
  label: 'Markup'
}, {
  value: 'nix',
  label: 'Nix'
}, {
  value: 'objectivec',
  label: 'Objective-C'
}, {
  value: 'ocaml',
  label: 'OCaml'
}, {
  value: 'pascal',
  label: 'Pascal'
}, {
  value: 'perl',
  label: 'Perl'
}, {
  value: 'php',
  label: 'PHP'
}, {
  value: 'powershell',
  label: 'PowerShell'
}, {
  value: 'prolog',
  label: 'Prolog'
}, {
  value: 'python',
  label: 'Python'
}, {
  value: 'r',
  label: 'R'
}, {
  value: 'reason',
  label: 'Reason'
}, {
  value: 'ruby',
  label: 'Ruby'
}, {
  value: 'rust',
  label: 'Rust'
}, {
  value: 'sass',
  label: 'Sass'
}, {
  value: 'scala',
  label: 'Scheme'
}, {
  value: 'scss',
  label: 'Scss'
}, {
  value: 'shell',
  label: 'Shell'
}, {
  value: 'sql',
  label: 'SQL'
}, {
  value: 'swift',
  label: 'Swift'
}, {
  value: 'typescript',
  label: 'Typescript'
}, {
  value: 'vbnet',
  label: 'VB.Net'
}, {
  value: 'verilog',
  label: 'Verilog'
}, {
  value: 'vhdl',
  label: 'VHDL'
}, {
  value: 'visual-basic',
  label: 'Visual Basic'
}, {
  value: 'wasm',
  label: 'WebAssembly'
}, {
  value: 'xml-doc',
  label: 'XML'
}, {
  value: 'yaml',
  label: 'YAML'
}];

const ElementCode = ({
  attributes,
  children,
  element,
  onSetLanguage
}) => {
  const {
    Button,
    Popover,
    List,
    MenuItem,
    TextField
  } = (0, _core.useUI)();
  const buttonRef = (0, _react.useRef)(null);
  const [filter, setFilter] = (0, _react.useState)('');
  const [selectOpen, setSelectOpen] = (0, _react.useState)(false);
  const [language, setLanguage] = (0, _react.useState)(element.language);
  const selectedLanguage = languages.find(({
    value
  }) => value === language);
  let label = 'Unknown';

  if (selectedLanguage) {
    label = selectedLanguage.label;
  }

  const handleSearch = (0, _react.useCallback)(event => {
    setFilter(event.target.value);
  }, []);
  const handleClose = (0, _react.useCallback)(() => {
    setSelectOpen(false);
    setTimeout(() => {
      setFilter('');
    }, 1000);
  }, []);
  const handleClickOption = (0, _react.useCallback)(value => {
    setLanguage(value);
    onSetLanguage(element, value);
    handleClose();
  }, [handleClose, onSetLanguage]);
  return _react.default.createElement("div", {
    style: {
      margin: '8px 0',
      borderRadius: 3,
      backgroundColor: '#F7F6F3',
      position: 'relative'
    }
  }, _react.default.createElement("code", _extends({}, attributes, {
    style: {
      display: 'block',
      fontSize: '14px',
      lineHeight: '20px',
      padding: '32px 16px',
      fontFamily: 'SFMono-Regular, Consolas, "Liberation Mono", Menlo, Courier, monospace'
    }
  }), children), _react.default.createElement("div", {
    contentEditable: false,
    style: {
      position: 'absolute',
      bottom: 8,
      right: 8
    }
  }, _react.default.createElement(Button, {
    style: {
      border: 0,
      color: '#757575'
    },
    ref: buttonRef,
    onClick: () => setSelectOpen(true),
    endIcon: _react.default.createElement(_DropdownIcon.DropdownIcon, null)
  }, label), _react.default.createElement(Popover, {
    open: selectOpen,
    anchorEl: buttonRef.current,
    onClose: handleClose,
    anchorOrigin: {
      vertical: 'bottom',
      horizontal: 'center'
    },
    transformOrigin: {
      vertical: 'top',
      horizontal: 'center'
    }
  }, _react.default.createElement("div", {
    style: {
      maxHeight: 300,
      position: 'relative'
    }
  }, _react.default.createElement("div", {
    style: {
      padding: 14,
      backgroundColor: '#FFF'
    }
  }, _react.default.createElement(TextField, {
    autoFocus: true,
    onChange: handleSearch,
    style: {
      width: '100%'
    },
    placeholder: "Search for a language"
  })), _react.default.createElement(List, {
    style: {
      maxHeight: 230,
      overflowY: 'scroll'
    }
  }, languages.filter(lang => lang.label.toLocaleLowerCase().includes(filter.toLowerCase())).map(lang => _react.default.createElement(MenuItem, {
    key: lang.value,
    onClick: () => handleClickOption(lang.value)
  }, lang.label)))))));
};

var _default = ElementCode;
exports.default = _default;
//# sourceMappingURL=ElementCode.js.map